==> dstruct-0.1.4.jar: META-INF/leiningen/thi.ng/dstruct/project.clj <==
(defproject thi.ng/dstruct "0.1.4"
  :description  "Data structures & utilities for CLJ/CLJS"
  :url          "http://thi.ng/dstruct"
  :license      {:name "Apache Software License 2.0"
                 :url "http://www.apache.org/licenses/LICENSE-2.0"
                 :distribution :repo}
  :scm          {:name "git"
                 :url "git@github.com:thi-ng/dstruct.git"}

  :min-lein-vesion "2.4.0"

  :dependencies [[org.clojure/clojure "1.8.0"]
                 [org.clojure/clojurescript "1.7.228"]
                 [thi.ng/math "0.2.1"]
                 ]

  :source-paths ["src"]
  :test-paths   ["test"]

  :profiles     {:dev {:dependencies [[criterium "0.4.3"]]
                       :plugins [[lein-cljsbuild "1.1.3"]
                                 [com.cemerick/clojurescript.test "0.3.3"]]
                       :global-vars {*warn-on-reflection* true}
                       :jvm-opts ^:replace []
                       :aliases {"cleantest" ["do" "clean," "test," "cljsbuild" "test"]}}}

  :cljsbuild    {:builds [{:id "simple"
                           :source-paths ["src" "test"]
                           :compiler {:output-to "target/dstruct-0.1.4.js"
                                      :optimizations :whitespace
                                      :parallel-build true
                                      :static-fns true
                                      :pretty-print true}}]
                 :test-commands {"unit-tests" ["phantomjs" :runner "target/dstruct-0.1.4.js"]}}

  :pom-addition [:developers [:developer
                              [:name "Karsten Schmidt"]
                              [:url "http://postspectacular.com"]
                              [:timezone "0"]]])

==> dstruct-0.2.0-20160403.120141-1.jar: META-INF/leiningen/thi.ng/dstruct/project.clj <==
(defproject thi.ng/dstruct "0.2.0-SNAPSHOT"
  :description  "Data structures & utilities for CLJ/CLJS"
  :url          "http://thi.ng/dstruct"
  :license      {:name "Apache Software License 2.0"
                 :url "http://www.apache.org/licenses/LICENSE-2.0"
                 :distribution :repo}
  :scm          {:name "git"
                 :url "git@github.com:thi-ng/dstruct.git"}

  :min-lein-vesion "2.4.0"

  :dependencies [[org.clojure/clojure "1.8.0"]
                 [org.clojure/clojurescript "1.8.40"]
                 [thi.ng/math "0.2.1"]
                 [thi.ng/xerror "0.1.0"]]

  :source-paths ["src"]
  :test-paths   ["test"]

  :profiles     {:dev {:dependencies [[criterium "0.4.4"]]
                       :plugins [[lein-cljsbuild "1.1.3"]
                                 [com.cemerick/clojurescript.test "0.3.3"]]
                       :global-vars {*warn-on-reflection* true}
                       :jvm-opts ^:replace []
                       :aliases {"cleantest" ["do" "clean," "test," "cljsbuild" "test"]}}}

  :cljsbuild    {:builds [{:id "simple"
                           :source-paths ["src" "test"]
                           :compiler {:output-to "target/dstruct-0.2.0-SNAPSHOT.js"
                                      :optimizations :whitespace
                                      :parallel-build true
                                      :static-fns true
                                      :pretty-print true}}]
                 :test-commands {"unit-tests" ["phantomjs" :runner "target/dstruct-0.2.0-SNAPSHOT.js"]}}

  :pom-addition [:developers [:developer
                              [:name "Karsten Schmidt"]
                              [:url "http://postspectacular.com"]
                              [:timezone "0"]]])
